package com.six15.six15presentationdemo;

import android.app.Activity;
import android.app.Presentation;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.os.Handler;
import android.util.Log;
import android.view.Display;
import android.view.Surface;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.TextView;

public class PresentSlide extends Presentation {
    private static final String TAG = "PresentSlide";

    private int mDefaultDisplayOrientation = Surface.ROTATION_0;
    private Handler mTimerHandler;

    static TextView timeTextView;
    static long startTime;

    public PresentSlide(Context context, Display display) {
        super(context, display);
        mTimerHandler = new Handler();
        if (context instanceof Activity) {
            Activity activity = (Activity) context;
            display = activity.getWindowManager().getDefaultDisplay();
            mDefaultDisplayOrientation = display.getRotation();
        }
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.d(TAG, "onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_present_slide);

        TextView tv = (TextView) findViewById(R.id.textView);
        Animation myRotation = AnimationUtils.loadAnimation(getContext(), R.anim.rotator);
        tv.startAnimation(myRotation);

        timeTextView = (TextView) findViewById(R.id.tv_time);
    }

    @Override
    protected  void onStart(){
        Log.d(TAG, "onStart");
        super.onStart();
        startTime = System.currentTimeMillis();
        final Runnable timerRunnable = new Runnable() {
            @Override
            public void run() {
                long millis = System.currentTimeMillis() - startTime;
                int seconds = (int) (millis / 1000);
                int minutes = seconds / 60;
                seconds = seconds % 60;
                timeTextView.setText(String.format("%d:%02d", minutes, seconds));
                mTimerHandler.postDelayed(this, 500);
            }
        };
        mTimerHandler.postDelayed(timerRunnable, 0);

        setOnDismissListener(new OnDismissListener() {
            @Override
            public void onDismiss(DialogInterface dialogInterface) {
                Log.i(TAG, "onDismiss");
                mTimerHandler.removeCallbacks(timerRunnable);
            }
        });

    }

    @Override
    protected void onStop() {
        Log.d(TAG, "onStop");
    }
}
